@@ -1,15 +1,8 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# imports.
-import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, time, random, threading, urllib, flask, logging, multiprocessing
-
-# inc imports.
-import cl1
-from fil3s import Files, Formats
-from r3sponse import r3sponse
-
-# fyunctions.
+# defaults.
+import os,sys,json
 def __get_operating_system__():
 	os = platform.system().lower()
 	if os in ["darwin"]: return "osx"
@@ -45,7 +38,7 @@ def __check_alias__(
 		base = f"/usr/bin/"
 	path = f"{base}/{alias}"
 	if present or not os.path.exists(path):
-		file = f"""#!/usr/bin/env python3\nimport os, sys\npackage="{executable}"\nsys.argv.pop(0)\narguments = sys.argv\ns = ""\nfor i in arguments:\n	if s == "": \n		if " " in i: s = "'"+i+"'"\n		else: s = i\n	else: \n		if " " in i: s += " '"+i+"'"\n		else: s += " "+i\nos.system("python3 "+package+" "+s)"""
+		file = f"""#!/usr/bin/env python3\nimport os, sys\npackage="{executable}"\nsys.argv.pop(0)\narguments = sys.argv\ns = ""\nfor i in arguments:\n	if s == "": \n		if " " in i: s = "'"+i+"'"\n		else: s = i\n	else: \n		if " " in i: s += " '"+i+"'"\n		else: s += " "+i\nif os.path.exists("/usr/bin/python3"): os.system("/usr/bin/python3 "+package+" "+s)\nelse:  os.system("python3 "+package+" "+s)"""
 
 		os.system(f"touch {path}")
 		os.system(f"chmod +x {path}")
@@ -68,6 +61,28 @@ SOURCE_NAME = "syst3m"
 SOURCE_PATH= __get_source_path__(__file__, back=3)
 OS = __get_operating_system__()
 
+# imports.
+def imports():
+	
+	# pip imports.
+	import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, time, random, threading, urllib, flask, logging, multiprocessing
+
+	# inc imports.
+	import cl1
+	from fil3s import Files, Formats
+	from r3sponse import r3sponse
+
+	#
+def safe_imports(reattempt=True, imports=imports):
+	try: imports()
+	except ImportError as e:
+		if not reattempt: raise ImportError(e)
+		if os.path.exists("/usr/bin/pip3"): 
+			os.system(f"/usr/bin/pip3 install -r {SOURCE_PATH}/requirements/requirements.txt --user {OWNER}")
+		else:
+			os.system(f"pip3 install -r {SOURCE_PATH}/requirements/requirements.txt")
+safe_imports()
+
 # universal variables.
 USER = os.environ.get("USER")
 OWNER = os.environ.get("USER")
