@@ -6,6 +6,18 @@ from syst3m.classes.config import *
 from syst3m.classes import utils, console
 import platform 
 
+# safe imports.
+def imports():
+	a=1
+def safe_imports(reattempt=True, imports=imports):
+	try: imports()
+	except ImportError as e:
+		if not reattempt: raise ImportError(e)
+		if os.path.exists("/usr/bin/pip3"): 
+			os.system(f"/usr/bin/pip3 install -r {SOURCE_PATH}/requirements/requirements.txt --user {OWNER}")
+		else:
+			os.system(f"pip3 install -r {SOURCE_PATH}/requirements/requirements.txt")
+
 # kill pid.
 def kill(
 	# the process id.
@@ -107,7 +119,7 @@ class Defaults(object):
 		if cl1.argument_present("--force") or cl1.argument_present("--forced") or overwrite or present or not os.path.exists(path):
 			if l_alias != None: alias = l_alias
 			#file = f"""package={executable}/\nargs=""\nfor var in "$@" ; do\n   	if [ "$args" == "" ] ; then\n   		args=$var\n   	else\n   		args=$args" "$var\n   	fi\ndone\npython3 $package $args\n"""
-			file = f"""#!/usr/bin/env python3\nimport os, sys\npackage="{executable}"\nsys.argv.pop(0)\narguments = sys.argv\ns = ""\nfor i in arguments:\n	if s == "": \n		if " " in i: s = "'"+i+"'"\n		else: s = i\n	else: \n		if " " in i: s += " '"+i+"'"\n		else: s += " "+i\nos.system("python3 "+package+" "+s)"""
+			file = f"""#!/usr/bin/env python3\nimport os, sys\npackage="{executable}"\nsys.argv.pop(0)\narguments = sys.argv\ns = ""\nfor i in arguments:\n	if s == "": \n		if " " in i: s = "'"+i+"'"\n		else: s = i\n	else: \n		if " " in i: s += " '"+i+"'"\n		else: s += " "+i\nif os.path.exists("/usr/bin/python3"): os.system("/usr/bin/python3 "+package+" "+s)\nelse:  os.system("python3 "+package+" "+s)"""
 			os.system(f"{sudo}touch {path}")
 			os.system(f"{sudo}chmod +x {path}")
 			os.system(f"{sudo}chown {self.user}:{self.group} {path}")
